{% extends "base.html" %}{% block content %}
<div class="page-header">
 <div class="titles"><h1>New VM</h1></div>
</div>
<div class="card" style="max-width:540px">
 <form class="form-stack" method="post" action="/vms">
  <p><label class="field">Name</label><input name="name" required style="width:100%"></p>
  <p><label class="field">Flavor</label><select name="flavor" style="width:100%">{% for f in flavors %}<option>{{ f.name }}</option>{% endfor %}</select></p>
  <p><label class="field">Image</label><select name="image" style="width:100%">{% for i in images %}<option>{{ i.name }}</option>{% endfor %}</select></p>
  <p><label class="field">Network</label><select name="network" style="width:100%"><option value="">(default)</option>{% for n in networks %}<option>{{ n.name }}</option>{% endfor %}</select></p>
  <p><label><input type="checkbox" name="floating_ip" value="true"> Attach floating IP</label></p>
  <p><button class="primary">Create</button> <a class="btn" href="/vms">cancel</a></p>
 </form>
</div>
{% endblock %}
