{% extends "base.html" %}{% block content %}
<div class="page-header">
 <div class="titles"><h1 class="error-title">Error {{ status }}</h1></div>
</div>
<div class="card">
 <p>{{ error }}</p>
 <p><a class="btn" href="/">← back to dashboard</a></p>
</div>
{% endblock %}
