{% extends "base.html" %}{% block content %}
<div class="page-header">
 <div class="titles"><h1>Keypairs</h1></div>
</div>
<div class="table-wrap">
<table>
<thead><tr><th>Name</th><th>Fingerprint</th><th class="actions"></th></tr></thead>
<tbody>
{% for k in keypairs %}
<tr>
 <td>{{ k.name }}</td><td class="mono">{{ k.fingerprint }}</td>
 <td class="actions"><form class="inline" method="post" action="/keypairs/{{ k.name }}/delete"><button class="danger">delete</button></form></td>
</tr>
{% else %}<tr><td colspan="3" class="muted">No keypairs.</td></tr>{% endfor %}
</tbody>
</table>
</div>
<div class="card" style="max-width:620px">
 <p class="card-title">Add keypair</p>
 <form class="form-stack" method="post" action="/keypairs">
  <p><label class="field">Name</label><input name="name" required></p>
  <p><label class="field">Public key</label><textarea name="public_key" rows="3" placeholder="ssh-ed25519 AAAA..." required></textarea></p>
  <button class="primary">Add</button>
 </form>
</div>
{% endblock %}
