{% extends "base.html" %}{% block content %}
<div class="page-header">
 <div class="titles"><h1>{{ container }}</h1><p class="subtitle"><a href="/objects">← all containers</a></p></div>
</div>
<div class="table-wrap">
<table>
<thead><tr><th>Object</th><th class="num">Bytes</th><th>Content-Type</th><th class="actions"></th></tr></thead>
<tbody>
{% for o in objects %}
<tr>
 <td>{{ o.name }}</td><td class="num">{{ o.bytes }}</td><td class="mono">{{ o.content_type }}</td>
 <td class="actions">
  <a class="btn" href="/objects/{{ container }}/{{ o.name }}/download">download</a>
  <form class="inline" method="post" action="/objects/{{ container }}/{{ o.name }}/delete"><button class="danger">delete</button></form>
 </td>
</tr>
{% else %}<tr><td colspan="4" class="muted">No objects.</td></tr>{% endfor %}
</tbody>
</table>
</div>
<div class="card" style="max-width:540px">
 <p class="card-title">Upload</p>
 <form class="form-row" method="post" action="/objects/{{ container }}/upload" enctype="multipart/form-data">
  <input type="file" name="file" required> <button class="primary">Upload</button>
 </form>
</div>
{% endblock %}
