{% extends "base.html" %}{% block content %}
<div class="page-header">
 <div class="titles"><h1>Floating IPs</h1></div>
</div>
<div class="table-wrap">
<table>
<thead><tr><th>Address</th><th>Attached to</th><th class="actions"></th></tr></thead>
<tbody>
{% for f in fips %}
<tr>
 <td class="mono">{{ f.address }}</td>
 <td class="mono">{{ f.attached_server_id or "—" }}</td>
 <td class="actions"><form class="inline" method="post" action="/floating-ips/{{ f.address }}/release"><button class="danger">release</button></form></td>
</tr>
{% else %}<tr><td colspan="3" class="muted">No floating IPs.</td></tr>{% endfor %}
</tbody>
</table>
</div>
<div class="card" style="max-width:540px">
 <p class="card-title">Allocate</p>
 <form class="form-row" method="post" action="/floating-ips">
  <label class="field">Network<input name="network" placeholder="(default)"></label>
  <button class="primary">Allocate</button>
 </form>
</div>
{% endblock %}
