"""``mgf-cloud`` command-line entry point (delegates to :mod:`mgf.cloud.cli`)."""

from __future__ import annotations

import sys

from mgf.cloud.cli import build_parser, main

__all__ = ["build_parser", "main"]


if __name__ == "__main__":
    sys.exit(main())
