{% extends "base.html" %}{% block content %}
<div class="page-header">
 <div class="titles"><h1>Object storage</h1></div>
</div>
<div class="table-wrap">
<table>
<thead><tr><th>Container</th><th class="num">Objects</th><th class="num">Bytes</th><th class="actions"></th></tr></thead>
<tbody>
{% for c in containers %}
<tr>
 <td><a href="/objects/{{ c.name }}">{{ c.name }}</a></td>
 <td class="num">{{ c.object_count }}</td><td class="num">{{ c.bytes }}</td>
 <td class="actions"><form class="inline" method="post" action="/objects/{{ c.name }}/delete"><button class="danger">delete</button></form></td>
</tr>
{% else %}<tr><td colspan="4" class="muted">No containers.</td></tr>{% endfor %}
</tbody>
</table>
</div>
<div class="card" style="max-width:540px">
 <p class="card-title">Create container</p>
 <form class="form-row" method="post" action="/objects">
  <label class="field">Name<input name="name" required></label>
  <button class="primary">Create</button>
 </form>
</div>
{% endblock %}
